import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StorageError(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STORAGE_NO_ERROR: _ClassVar[StorageError]
    STORAGE_ALREADY_EXIST: _ClassVar[StorageError]
    STORAGE_NOT_FOUND: _ClassVar[StorageError]
    INTERNAL_SERVER_ERROR: _ClassVar[StorageError]

class ObjectError(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OBJECT_NO_ERROR: _ClassVar[ObjectError]
    OBJECT_ALREADY_EXIST: _ClassVar[ObjectError]
    OBJECT_SIZE_ERROR: _ClassVar[ObjectError]
    OBJECT_NOT_FOUND: _ClassVar[ObjectError]
    OBJECT_DIR_NOT_EMPTY: _ClassVar[ObjectError]

class CredentialsError(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CREDENTIALS_NO_ERROR: _ClassVar[CredentialsError]
STORAGE_NO_ERROR: StorageError
STORAGE_ALREADY_EXIST: StorageError
STORAGE_NOT_FOUND: StorageError
INTERNAL_SERVER_ERROR: StorageError
OBJECT_NO_ERROR: ObjectError
OBJECT_ALREADY_EXIST: ObjectError
OBJECT_SIZE_ERROR: ObjectError
OBJECT_NOT_FOUND: ObjectError
OBJECT_DIR_NOT_EMPTY: ObjectError
CREDENTIALS_NO_ERROR: CredentialsError

class Storage(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class Object(_message.Message):
    __slots__ = ("name", "type", "prefix", "size", "lastmodified")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    LASTMODIFIED_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    prefix: str
    size: str
    lastmodified: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., prefix: _Optional[str] = ..., size: _Optional[str] = ..., lastmodified: _Optional[str] = ...) -> None: ...

class StorageResponseError(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: StorageError
    message: str
    def __init__(self, code: _Optional[_Union[StorageError, str]] = ..., message: _Optional[str] = ...) -> None: ...

class ObjectResponseError(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: ObjectError
    message: str
    def __init__(self, code: _Optional[_Union[ObjectError, str]] = ..., message: _Optional[str] = ...) -> None: ...

class ObjectStorageCredentialsResponseError(_message.Message):
    __slots__ = ("code", "message")
    CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    code: CredentialsError
    message: str
    def __init__(self, code: _Optional[_Union[CredentialsError, str]] = ..., message: _Optional[str] = ...) -> None: ...

class StorageListRequest(_message.Message):
    __slots__ = ("storage", "object")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    object: Object
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class StorageListResponse(_message.Message):
    __slots__ = ("storage", "error")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    storage: _containers.RepeatedCompositeFieldContainer[Storage]
    error: StorageResponseError
    def __init__(self, storage: _Optional[_Iterable[_Union[Storage, _Mapping]]] = ..., error: _Optional[_Union[StorageResponseError, _Mapping]] = ...) -> None: ...

class StorageCreateRequest(_message.Message):
    __slots__ = ("storage",)
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ...) -> None: ...

class StorageCreateResponse(_message.Message):
    __slots__ = ("storage", "error")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    error: StorageResponseError
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., error: _Optional[_Union[StorageResponseError, _Mapping]] = ...) -> None: ...

class StorageDeleteRequest(_message.Message):
    __slots__ = ("storage",)
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ...) -> None: ...

class StorageDeleteResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: StorageResponseError
    def __init__(self, error: _Optional[_Union[StorageResponseError, _Mapping]] = ...) -> None: ...

class StorageListObjectRequest(_message.Message):
    __slots__ = ("storage", "object")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    object: Object
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class StorageListObjectResponse(_message.Message):
    __slots__ = ("object", "error")
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    object: _containers.RepeatedCompositeFieldContainer[Object]
    error: StorageResponseError
    def __init__(self, object: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., error: _Optional[_Union[StorageResponseError, _Mapping]] = ...) -> None: ...

class ObjectCreateRequest(_message.Message):
    __slots__ = ("storage", "object")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    object: Object
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class ObjectCreateResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: ObjectResponseError
    def __init__(self, error: _Optional[_Union[ObjectResponseError, _Mapping]] = ...) -> None: ...

class ObjectListRequest(_message.Message):
    __slots__ = ("storage", "object")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    object: Object
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class ObjectListResponse(_message.Message):
    __slots__ = ("object", "error")
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    object: _containers.RepeatedCompositeFieldContainer[Object]
    error: ObjectResponseError
    def __init__(self, object: _Optional[_Iterable[_Union[Object, _Mapping]]] = ..., error: _Optional[_Union[ObjectResponseError, _Mapping]] = ...) -> None: ...

class ObjectGetRequest(_message.Message):
    __slots__ = ("storage", "object")
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    object: Object
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ..., object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class ObjectGetResponse(_message.Message):
    __slots__ = ("object", "error")
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    object: Object
    error: ObjectResponseError
    def __init__(self, object: _Optional[_Union[Object, _Mapping]] = ..., error: _Optional[_Union[ObjectResponseError, _Mapping]] = ...) -> None: ...

class ObjectDeleteRequest(_message.Message):
    __slots__ = ("object",)
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: Object
    def __init__(self, object: _Optional[_Union[Object, _Mapping]] = ...) -> None: ...

class ObjectDeleteResponse(_message.Message):
    __slots__ = ("error",)
    ERROR_FIELD_NUMBER: _ClassVar[int]
    error: ObjectResponseError
    def __init__(self, error: _Optional[_Union[ObjectResponseError, _Mapping]] = ...) -> None: ...

class ObjectStorageS3Credentials(_message.Message):
    __slots__ = ("endpoint_url", "region_name", "access_key_id", "secret_key", "session_token", "expiration")
    ENDPOINT_URL_FIELD_NUMBER: _ClassVar[int]
    REGION_NAME_FIELD_NUMBER: _ClassVar[int]
    ACCESS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    SESSION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    endpoint_url: str
    region_name: str
    access_key_id: str
    secret_key: str
    session_token: str
    expiration: str
    def __init__(self, endpoint_url: _Optional[str] = ..., region_name: _Optional[str] = ..., access_key_id: _Optional[str] = ..., secret_key: _Optional[str] = ..., session_token: _Optional[str] = ..., expiration: _Optional[str] = ...) -> None: ...

class ObjectStorageAzureCredentials(_message.Message):
    __slots__ = ("endpoint_url", "access_key_id", "secret_key")
    ENDPOINT_URL_FIELD_NUMBER: _ClassVar[int]
    ACCESS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_KEY_FIELD_NUMBER: _ClassVar[int]
    endpoint_url: str
    access_key_id: str
    secret_key: str
    def __init__(self, endpoint_url: _Optional[str] = ..., access_key_id: _Optional[str] = ..., secret_key: _Optional[str] = ...) -> None: ...

class ObjectStorageCredentials(_message.Message):
    __slots__ = ("s3",)
    S3_FIELD_NUMBER: _ClassVar[int]
    s3: ObjectStorageS3Credentials
    def __init__(self, s3: _Optional[_Union[ObjectStorageS3Credentials, _Mapping]] = ...) -> None: ...

class ObjectStorageCredentialsRequest(_message.Message):
    __slots__ = ("storage",)
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    storage: Storage
    def __init__(self, storage: _Optional[_Union[Storage, _Mapping]] = ...) -> None: ...

class ObjectStorageCredentialsResponse(_message.Message):
    __slots__ = ("credentials", "error")
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    credentials: ObjectStorageCredentials
    error: ObjectStorageCredentialsResponseError
    def __init__(self, credentials: _Optional[_Union[ObjectStorageCredentials, _Mapping]] = ..., error: _Optional[_Union[ObjectStorageCredentialsResponseError, _Mapping]] = ...) -> None: ...

class StorageObjectPublicUrlRequest(_message.Message):
    __slots__ = ("workspace_id", "storage_name", "prefix", "object_name")
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    STORAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    OBJECT_NAME_FIELD_NUMBER: _ClassVar[int]
    workspace_id: str
    storage_name: str
    prefix: str
    object_name: str
    def __init__(self, workspace_id: _Optional[str] = ..., storage_name: _Optional[str] = ..., prefix: _Optional[str] = ..., object_name: _Optional[str] = ...) -> None: ...

class StorageObjectPublicUrlResponse(_message.Message):
    __slots__ = ("url", "error")
    URL_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    url: str
    error: ObjectResponseError
    def __init__(self, url: _Optional[str] = ..., error: _Optional[_Union[ObjectResponseError, _Mapping]] = ...) -> None: ...



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.3.3.1](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.12.3 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import ConfigDict
from pydantic import Field
import typing

class Error(IntEnum):#  Generic errors 0 - 199
    NO_ERROR = 0
    INTERNAL_SERVER_ERROR = 199
    IAM_USER_NOT_FOUND = 200
    IAM_USER_NOT_AUTHORIZED = 201
    IAM_API_KEY_ALREADY_EXISTS = 202
    WORKSPACE_NOT_FOUND = 300
    WORKSPACE_USER_ALREADY_EXISTS = 302
    WORKSPACE_USER_NOT_FOUND = 303
    WORKSPACE_USER_ALREADY_ACTIVE = 304
    WORKSPACE_USER_ALREADY_HAVE_PERSONAL_WORKSPACE = 305
    WORKSPACE_PLUGIN_NOT_FOUND = 306
    WORKSPACE_INVITE_INVALID = 307
    WORKSPACE_CANNOT_INVITE_TO_PERSONAL_WORKSPACE = 308
    CREDITS_USER_HAS_NO_PARENT = 400
    CREDITS_OUT_OF_CREDITS = 401
    CREDITS_USER_ALREADY_HAS_PARENT = 402
    ONTOLOGY_NOT_FOUND = 500
    CHAT_NOT_FOUND = 600
    CHAT_NOT_AUTHORIZED = 601
    CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXIST = 602
    CHAT_CONTEXT_LENGTH_EXCEEDED = 603
    CHAT_MESSAGE_ALREADY_EXISTS = 604
    CHAT_MESSAGE_NOT_FOUND = 605
    CHAT_INTERNAL_SERVER_ERROR = 699
    AIMODEL_NOT_FOUND = 700
    ASSET_NOT_FOUND = 800
    ASSET_ALREADY_EXISTS = 801
    ASSET_REQUEST_ERROR = 802

class ErrorResponse(BaseModel):
    model_config = ConfigDict(validate_default=True)
    code: typing.Optional[Error] = Field(default=0)
    message: typing.Optional[str] = Field(default="")
    context: typing.Optional[str] = Field(default="")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aimodel.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raimodel.proto\x12\x07\x61imodel\x1a\x0evalidate.proto\"\xc7\x02\n\x07\x41IModel\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08provider\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05image\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x14\n\x07\x65nabled\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x11\n\x04type\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nrestricted\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nname_alias\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1b\n\x0e\x63ontext_window\x18\t \x01(\x05H\x08\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_providerB\x08\n\x06_imageB\n\n\x08_enabledB\x07\n\x05_typeB\r\n\x0b_restrictedB\r\n\x0b_name_aliasB\x11\n\x0f_context_window\"\x8f\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08model_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x13\n\x0b\x63ompletions\x18\x02 \x03(\t\x12\x19\n\x0cinput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x06 \x01(\x05H\x04\x88\x01\x01\x42\x0b\n\t_model_idB\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_steps\"\xab\x01\n\x14\x41IModelResponseError\x12(\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.aimodel.AIModelErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"d\n\x12\x41IModelListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"\xa0\x01\n\x13\x41IModelListResponse\x12\"\n\x08\x61imodels\x18\x01 \x03(\x0b\x32\x10.aimodel.AIModel\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\x0e\n\x0c_page_numberB\x08\n\x06_error\"5\n\x11\x41IModelGetRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x85\x01\n\x12\x41IModelGetResponse\x12&\n\x07\x61imodel\x18\x01 \x01(\x0b\x32\x10.aimodel.AIModelH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_aimodelB\x08\n\x06_error\"^\n\x18\x41IModelCompletionRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_payload\"\x9d\x01\n\x19\x41IModelCompletionResponse\x12\x34\n\ncompletion\x18\x01 \x01(\x0b\x32\x1b.aimodel.CompletionResponseH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error\"\x89\x02\n\x1b\x41IModelAdminCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08provider\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05image\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07\x65nabled\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x17\n\nrestricted\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x17\n\nname_alias\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_providerB\x08\n\x06_imageB\n\n\x08_enabledB\x07\n\x05_typeB\r\n\x0b_restrictedB\r\n\x0b_name_alias\"\x8f\x01\n\x1c\x41IModelAdminCreationResponse\x12&\n\x07\x61imodel\x18\x01 \x01(\x0b\x32\x10.aimodel.AIModelH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_aimodelB\x08\n\x06_error\"=\n\x19\x41IModelAdminDeleteRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x05\n\x03_id\"Y\n\x1a\x41IModelAdminDeleteResponse\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\xa4\x01\n\x0c\x41IModelError\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x12\x0f\n\x0bNOT_UPDATED\x10\x03\x12\x12\n\x0eNOT_AUTHORIZED\x10\x04\x12\x1a\n\x16\x41IMODEL_OUT_OF_CREDITS\x10\x05\x12\"\n\x1e\x41IMODEL_DONT_HANDLE_COMPLETION\x10\x06\x42\x30Z.github.com/jupyter-naas/naas-models/go/aimodelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aimodel_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/aimodel'
  _globals['_AIMODEL'].fields_by_name['id']._loaded_options = None
  _globals['_AIMODEL'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_COMPLETIONRESPONSE'].fields_by_name['model_id']._loaded_options = None
  _globals['_COMPLETIONRESPONSE'].fields_by_name['model_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_AIMODELGETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_AIMODELGETREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_AIMODELCOMPLETIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_AIMODELCOMPLETIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_AIMODELADMINDELETEREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_AIMODELADMINDELETEREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_AIMODELERROR']._serialized_start=2101
  _globals['_AIMODELERROR']._serialized_end=2265
  _globals['_AIMODEL']._serialized_start=43
  _globals['_AIMODEL']._serialized_end=370
  _globals['_COMPLETIONRESPONSE']._serialized_start=373
  _globals['_COMPLETIONRESPONSE']._serialized_end=644
  _globals['_AIMODELRESPONSEERROR']._serialized_start=647
  _globals['_AIMODELRESPONSEERROR']._serialized_end=818
  _globals['_AIMODELLISTREQUEST']._serialized_start=820
  _globals['_AIMODELLISTREQUEST']._serialized_end=920
  _globals['_AIMODELLISTRESPONSE']._serialized_start=923
  _globals['_AIMODELLISTRESPONSE']._serialized_end=1083
  _globals['_AIMODELGETREQUEST']._serialized_start=1085
  _globals['_AIMODELGETREQUEST']._serialized_end=1138
  _globals['_AIMODELGETRESPONSE']._serialized_start=1141
  _globals['_AIMODELGETRESPONSE']._serialized_end=1274
  _globals['_AIMODELCOMPLETIONREQUEST']._serialized_start=1276
  _globals['_AIMODELCOMPLETIONREQUEST']._serialized_end=1370
  _globals['_AIMODELCOMPLETIONRESPONSE']._serialized_start=1373
  _globals['_AIMODELCOMPLETIONRESPONSE']._serialized_end=1530
  _globals['_AIMODELADMINCREATIONREQUEST']._serialized_start=1533
  _globals['_AIMODELADMINCREATIONREQUEST']._serialized_end=1798
  _globals['_AIMODELADMINCREATIONRESPONSE']._serialized_start=1801
  _globals['_AIMODELADMINCREATIONRESPONSE']._serialized_end=1944
  _globals['_AIMODELADMINDELETEREQUEST']._serialized_start=1946
  _globals['_AIMODELADMINDELETEREQUEST']._serialized_end=2007
  _globals['_AIMODELADMINDELETERESPONSE']._serialized_start=2009
  _globals['_AIMODELADMINDELETERESPONSE']._serialized_end=2098
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: iam.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2
import naas_models.errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tiam.proto\x12\x03iam\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\x8b\x01\n\tTokenData\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06scopes\x18\x02 \x03(\t\x12\x17\n\napi_key_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tjwt_token\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_user_idB\r\n\x0b_api_key_idB\x0c\n\n_jwt_token\"\xc7\x03\n\x07Profile\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nfirst_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tlast_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07\x63ompany\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04role\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08timezone\x18\x06 \x01(\tH\x05\x88\x01\x01\x12 \n\x13profile_picture_url\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1e\n\x11user_presentation\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x19\n\x0ctargeted_use\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1c\n\x0fproduct_updates\x18\n \x01(\x08H\t\x88\x01\x01\x12\x12\n\x05phone\x18\x0b \x01(\tH\n\x88\x01\x01\x42\n\n\x08_user_idB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\n\n\x08_companyB\x07\n\x05_roleB\x0b\n\t_timezoneB\x16\n\x14_profile_picture_urlB\x14\n\x12_user_presentationB\x0f\n\r_targeted_useB\x12\n\x10_product_updatesB\x08\n\x06_phone\"W\n\x16ImpersonateUserRequest\x12\x1b\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x18\n\x05\x65mail\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02`\x01H\x00\x42\x06\n\x04user\"l\n\x17ImpersonateUserResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12\x12\n\x05token\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x08\n\x06_token\"\xd2\x01\n\x06\x41piKey\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x61pi_key\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x17\n\ncreated_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_user_idB\n\n\x08_api_keyB\x07\n\x05_nameB\x0e\n\x0c_descriptionB\r\n\x0b_created_at\"V\n\x0e\x41piKeyCreation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_description\"L\n\x13\x43reateApiKeyRequest\x12)\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32\x13.iam.ApiKeyCreationH\x00\x88\x01\x01\x42\n\n\x08_api_key\"z\n\x14\x43reateApiKeyResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12!\n\x07\x61pi_key\x18\x02 \x01(\x0b\x32\x0b.iam.ApiKeyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\n\n\x08_api_key\"6\n\x12ListApiKeysRequest\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_user_id\"i\n\x13ListApiKeysResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12\x1d\n\x08\x61pi_keys\x18\x02 \x03(\x0b\x32\x0b.iam.ApiKeyB\x08\n\x06_errorB,Z*github.com/jupyter-naas/naas-models/go/iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iam_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*github.com/jupyter-naas/naas-models/go/iam'
  _globals['_IMPERSONATEUSERREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_IMPERSONATEUSERREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_IMPERSONATEUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_IMPERSONATEUSERREQUEST'].fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _globals['_TOKENDATA']._serialized_start=49
  _globals['_TOKENDATA']._serialized_end=188
  _globals['_PROFILE']._serialized_start=191
  _globals['_PROFILE']._serialized_end=646
  _globals['_IMPERSONATEUSERREQUEST']._serialized_start=648
  _globals['_IMPERSONATEUSERREQUEST']._serialized_end=735
  _globals['_IMPERSONATEUSERRESPONSE']._serialized_start=737
  _globals['_IMPERSONATEUSERRESPONSE']._serialized_end=845
  _globals['_APIKEY']._serialized_start=848
  _globals['_APIKEY']._serialized_end=1058
  _globals['_APIKEYCREATION']._serialized_start=1060
  _globals['_APIKEYCREATION']._serialized_end=1146
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=1148
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=1224
  _globals['_CREATEAPIKEYRESPONSE']._serialized_start=1226
  _globals['_CREATEAPIKEYRESPONSE']._serialized_end=1348
  _globals['_LISTAPIKEYSREQUEST']._serialized_start=1350
  _globals['_LISTAPIKEYSREQUEST']._serialized_end=1404
  _globals['_LISTAPIKEYSRESPONSE']._serialized_start=1406
  _globals['_LISTAPIKEYSRESPONSE']._serialized_end=1511
# @@protoc_insertion_point(module_scope)
